'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const sdkRedux = require('@boldpenguin/sdk-redux');
const index_esm_min = require('./index.esm.min-bb87d5ab.js');
const store = require('./store-fe3d3434.js');

const bpSdkBackButtonContainerCss = "";

let BpSdkBackButtonContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    /**
     * Question sets
     */
    this.questionSets = [];
    this.useExternal = false;
    this.canSave = true;
    this.areResourcesReady = true;
    this.isReady = true;
    this.isFirstRun = true;
    this.isFirstQnSet = true;
    this.isDisabled = false;
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        if (this.storeUnsubscribe) {
          this.storeUnsubscribe();
        }
        store.store.mapDispatchToProps(this, {
          saveQuestionSet: sdkRedux.saveQuestionSet,
          updateErrors: sdkRedux.updateErrors,
          removeActiveAnswerId: sdkRedux.removeActiveAnswerId,
          switchActiveQuestionSet: sdkRedux.switchActiveQuestionSet,
        });
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        activeQuestionSet: sdkRedux.getCurrentActiveQuestionSet(state),
        config: sdkRedux.getPartnerEngineConfig(state),
        questionSets: sdkRedux.getQuestionSets(state),
        queue: state.queues.answers.queue,
        answersResourceState: sdkRedux.getAnswersState(state),
        applicationFormResourceState: sdkRedux.getApplicationFormState(state),
        questionPoolResourceState: sdkRedux.getQuestionPoolState(state),
        questionSetResourceState: sdkRedux.getQuestionSetState(state),
      };
    };
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-back-button-container');
    customElements.whenDefined('bp-sdk-external-back-button-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionSetsChange(this.questionSets);
    this.onActiveQuestionSetChange(this.activeQuestionSet);
    this.onIsReady(this.isReady);
    this.onAnswersResourcesStateChange(this.answersResourceState);
    this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
    this.onIsFirstRun(this.isFirstRun);
    this.onIsReady(this.isReady);
    this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
    this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
    this.onQueueChange(this.queue);
  }
  onIsReady(isReady) {
    this.updateAreResourcesReady(this.isFirstRun, isReady);
  }
  updateAreResourcesReady(isFirstRun, isReady) {
    this.areResourcesReady = isFirstRun || isReady;
  }
  onAnswersResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: state,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onApplicationFormResourceStateChange(state) {
    if (this.isFirstRun && state === index_esm_min.i.Loaded) {
      this.isFirstRun = false;
    }
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: state,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionPoolResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: state,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionSetResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: state,
    });
  }
  calculateResourcesReady(resources = {}) {
    if (!resources ||
      resources.applicationForm !== index_esm_min.i.Loaded ||
      resources.answers === index_esm_min.i.Loading ||
      resources.questionPools === index_esm_min.i.Loading ||
      resources.questionSets === index_esm_min.i.Loading) {
      return false;
    }
    return true;
  }
  onActiveQuestionSetChange(activeQuestionSet) {
    this.updateIsFirstQnSet(this.questionSets, activeQuestionSet);
  }
  onIsFirstRun(isFirstRun) {
    this.updateAreResourcesReady(isFirstRun, this.isReady);
  }
  onQuestionSetsChange(qns) {
    this.updateIsFirstQnSet(qns, this.activeQuestionSet);
  }
  updateIsFirstQnSet(qns, activeQns) {
    var _a;
    this.isFirstQnSet = ((_a = qns[0]) === null || _a === void 0 ? void 0 : _a.question_set_id) === (activeQns === null || activeQns === void 0 ? void 0 : activeQns.question_set_id);
  }
  onQueueChange(queue) {
    this.canSave = !(queue === null || queue === void 0 ? void 0 : queue.length);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-back-button-container", { activeQuestionSet: this.activeQuestionSet, answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, buttonDisabled: this.buttonDisabled, config: this.config, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSets: this.questionSets, queue: this.queue }));
  }
  handleNavigateBack() {
    this.switchActiveQuestionSet('backward');
  }
  renderInternal() {
    return (index.h("bp-sdk-back-button", { buttonDisabled: this.buttonDisabled || !this.areResourcesReady || !this.canSave || this.isFirstQnSet, cssClasses: !this.areResourcesReady || !this.canSave ? 'loading' : 'not-loading' }));
  }
  static get watchers() { return {
    "isReady": ["onIsReady"],
    "answersResourceState": ["onAnswersResourcesStateChange"],
    "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
    "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
    "questionSetResourceState": ["onQuestionSetResourcesStateChange"],
    "activeQuestionSet": ["onActiveQuestionSetChange"],
    "isFirstRun": ["onIsFirstRun"],
    "questionSets": ["onQuestionSetsChange"],
    "queue": ["onQueueChange"]
  }; }
};
BpSdkBackButtonContainer.style = bpSdkBackButtonContainerCss;

exports.bp_sdk_back_button_container = BpSdkBackButtonContainer;
