import { getUnansweredRefiltersByQuestionId } from '@boldpenguin/sdk-redux';
import { Component, Event, h, Prop, State } from '@stencil/core';
import { store } from '@stencil/redux';
import { canGetStore } from '../../utils/store';
export class BpSdkBusinessClassificationSelectorNudgeContainer {
  constructor() {
    /**
     * Nudges available in the Redux store
     */
    this.nudges = [];
    this.useExternal = false;
    /**
     * Are nudges hidden from UI?
     */
    this.isHidden = true;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        nudges: getUnansweredRefiltersByQuestionId(state, this.questionId),
      };
    };
    this.handleYesClick = (key, evt) => {
      if (evt && !this.useExternal) {
        evt.stopPropagation();
      }
      this.nudgeAnswer.emit({
        key,
        answer: true,
      });
    };
    this.handleNoClick = (key, evt) => {
      if (evt && !this.useExternal) {
        evt.stopPropagation();
      }
      this.nudgeAnswer.emit({
        key,
        answer: false,
      });
    };
  }
  resetState() {
    this.isHidden = true;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-nudge-container');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-nudge-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-nudge-container", { isHidden: this.isHidden, nudges: this.nudges, questionId: this.questionId }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-nudge-container__container" }, this.nudges.map((refilter) => (h("bp-sdk-business-classification-selector-nudge", { refilter: refilter, handleYesClick: this.handleYesClick, handleNoClick: this.handleNoClick })))));
  }
  static get is() { return "bp-sdk-business-classification-selector-nudge-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-business-classification-selector-nudge-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-business-classification-selector-nudge-container.css"]
  }; }
  static get properties() { return {
    "nudges": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IRefilter[]",
        "resolved": "IRefilter[]",
        "references": {
          "IRefilter": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Nudges available in the Redux store"
      },
      "defaultValue": "[]"
    },
    "questionId": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question ID for getting nudges from the store"
      },
      "attribute": "question-id",
      "reflect": false
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "isHidden": {}
  }; }
  static get events() { return [{
      "method": "nudgeAnswer",
      "name": "nudgeAnswer",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "This event should emit a boolean indicating if the user pressed yes/no for the refilter question"
      },
      "complexType": {
        "original": "{ key: number; answer: boolean }",
        "resolved": "{ key: number; answer: boolean; }",
        "references": {}
      }
    }]; }
}
