import { Component, h, State, Prop } from '@stencil/core';
export class BpSdkRadioDialog {
  constructor() {
    /**
     * Choices to display
     */
    this.choices = [];
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-radio-dialog');
    customElements.whenDefined('bp-sdk-external-radio-dialog').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-radio-dialog", { answeredBySource: this.answeredBySource, answerId: this.answerId, choiceId: this.choiceId, choices: this.choices, code: this.code, errorText: this.errorText, errors: this.errors, fieldType: this.fieldType, helpText: this.helpText, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, isRequired: this.isRequired, label: this.label, labelledBy: this.labelledBy, pristine: this.pristine, questionId: this.questionId, touched: this.touched }));
  }
  renderInternal() {
    return (h("bp-sdk-dialog", { class: "bp-sdk-radio-dialog__container", code: this.code, isRequired: this.isRequired, questionId: this.questionId },
      h("div", { class: "bp-sdk-radio-dialog__radio" },
        h("bp-sdk-radio-input", { answeredBySource: this.answeredBySource, answerId: this.answerId, choiceId: this.choiceId, choices: this.choices, code: this.code, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, label: this.label, labelledBy: this.labelledBy, pristine: this.pristine, questionId: this.questionId, required: this.isRequired, touched: this.touched }))));
  }
  static get is() { return "bp-sdk-radio-dialog"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-radio-dialog.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-radio-dialog.css"]
  }; }
  static get properties() { return {
    "answerId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Answer id"
      },
      "attribute": "answer-id",
      "reflect": false
    },
    "questionId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question id"
      },
      "attribute": "question_id",
      "reflect": false
    },
    "fieldType": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Field type"
      },
      "attribute": "field_type",
      "reflect": false
    },
    "code": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "question code"
      },
      "attribute": "code",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label to display"
      },
      "attribute": "label",
      "reflect": false
    },
    "labelledBy": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Labels that describe group"
      },
      "attribute": "labelled-by",
      "reflect": false
    },
    "choices": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IChoice[]",
        "resolved": "IChoice[]",
        "references": {
          "IChoice": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choices to display"
      },
      "defaultValue": "[]"
    },
    "choiceId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Selected choice"
      },
      "attribute": "choice-id",
      "reflect": false
    },
    "errors": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error messages"
      }
    },
    "errorText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error text"
      },
      "attribute": "error_text",
      "reflect": false
    },
    "touched": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is touched"
      },
      "attribute": "touched",
      "reflect": false,
      "defaultValue": "false"
    },
    "pristine": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is pristine"
      },
      "attribute": "pristine",
      "reflect": false,
      "defaultValue": "true"
    },
    "isRequired": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is required"
      },
      "attribute": "is-required",
      "reflect": false
    },
    "isReadOnly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When true, the field will be readonly. It will display only the label and value as plain text."
      },
      "attribute": "is-read-only",
      "reflect": false,
      "defaultValue": "false"
    },
    "isCompleted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is answer in complete state"
      },
      "attribute": "is_completed",
      "reflect": false,
      "defaultValue": "false"
    },
    "helpText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Help text"
      },
      "attribute": "help-text",
      "reflect": false
    },
    "answeredBySource": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | undefined",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifically how the question was answered (ie. \"ACORD 126\")"
      },
      "attribute": "answered-by-source",
      "reflect": false
    }
  }; }
  static get states() { return {
    "useExternal": {}
  }; }
}
