import { r as registerInstance, h, g as getElement } from './index-b4e0290f.js';
import { updateActiveQuestionSet, removeActiveAnswerId, getConfigOptions } from '@boldpenguin/sdk-redux';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';

let BpSdkQuestionSetNavigationContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
    this.questionSetList = [];
    this.isNavigationEnabled = true;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { updateActiveQuestionSet, removeActiveAnswerId });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        questionSets: state.application.questionSets,
        configOptions: getConfigOptions(state),
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-navigation-container');
    customElements.whenDefined('bp-sdk-external-question-set-navigation-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  onRemoveActiveAnswerRequest() {
    this.removeActiveAnswerId();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  handleActiveQuestionSetUpdate(evt) {
    if (this.useExternal) {
      return;
    }
    evt.detail && this.updateActiveQuestionSet(evt.detail);
    this.removeActiveAnswerId();
  }
  componentWillUpdate() {
    this.handleSubscriptions();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-set-navigation-container", { configOptions: this.configOptions, questionSets: this.questionSets });
  }
  onQuestionSetsChange(sets) {
    var _a;
    this.activeId = sets === null || sets === void 0 ? void 0 : sets.active;
    this.questionSetList = (_a = sets === null || sets === void 0 ? void 0 : sets.list) !== null && _a !== void 0 ? _a : [];
  }
  onConfigOptionsChange(options) {
    var _a;
    this.isNavigationEnabled = (_a = options === null || options === void 0 ? void 0 : options.enableQuestionSetNavigation) !== null && _a !== void 0 ? _a : true;
  }
  renderInternal() {
    if (!canGetStore()) {
      return null;
    }
    return (h("bp-sdk-question-set-navigation", { activeId: this.activeId, questionSets: this.questionSetList, isNavigationEnabled: this.isNavigationEnabled }));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionSets": ["onQuestionSetsChange"],
    "configOptions": ["onConfigOptionsChange"]
  }; }
};

export { BpSdkQuestionSetNavigationContainer as bp_sdk_question_set_navigation_container };
