import { r as registerInstance, c as createEvent, h, g as getElement } from './index-b4e0290f.js';
import { a as rx } from './index.esm.min-2fa80c01.js';

const bpSdkQuestionSetNavigationCss = ".bp-sdk-question-set-navigation__list-item-content{user-select:none}";

let BpSdkQuestionSetNavigation = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.activeIdUpdate = createEvent(this, "activeIdUpdate", 7);
    /**
     * Potential question sets
     */
    this.questionSets = [];
    /**
     * Question set navigation enabled/disabled
     */
    this.isNavigationEnabled = true;
    this.useExternal = false;
    this.updateQuestionSetId = (id) => () => {
      if (this.isNavigationEnabled) {
        this.activeId = id;
        this.activeIdUpdate.emit(id);
      }
    };
    this.onKeyDown = (e) => {
      if (e.key === 'ArrowUp' || e.key === 'ArrowDown') {
        e.preventDefault();
      }
    };
    this.onKeyUp = (e) => {
      var _a;
      const focused = this.el.querySelector(':focus').parentElement;
      const index = +((_a = focused.getAttribute('aria-posinset')) !== null && _a !== void 0 ? _a : -1);
      let target = this.getPosition(index, e.key);
      if (target != null) {
        const button = this.el.querySelector(`[aria-posinset='${target}'] > button`);
        button.focus();
      }
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-navigation');
    customElements.whenDefined('bp-sdk-external-question-set-navigation').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-question-set-navigation", { activeId: this.activeId, isNavigationEnabled: this.isNavigationEnabled, questionSets: this.questionSets }));
  }
  renderInternal() {
    return (h("nav", { class: "bp-sdk-question-set-navigation__container", "aria-label": "Question Sets", role: "navigation", onKeyDown: this.onKeyDown, onKeyUp: this.onKeyUp }, h("ul", { tabindex: "0", role: "list", class: "bp-sdk-question-set-navigation__list" }, this.questionSets
      .filter((set) => { var _a; return !!set.is_active && ((_a = set.answers) === null || _a === void 0 ? void 0 : _a.length) > 0; })
      .map((set, i) => {
      return (h("li", { class: rx('bp-sdk-question-set-navigation__list-item', {
          'bp-sdk-question-set-navigation__list-item--active': set.question_set_id === this.activeId,
          'bp-sdk-question-set-navigation__list-item--completed': set.is_completed,
        }), "aria-setsize": this.questionSets.length, "aria-posinset": i + 1 }, h("button", { type: "button", tabindex: "-1", class: "bp-sdk-question-set-navigation__list-item-button", onClick: this.updateQuestionSetId(set.question_set_id) }, h("div", { class: "bp-sdk-question-set-navigation__list-item-content" }, set.question_set.name))));
    }))));
  }
  getPosition(index, key) {
    let target;
    if (key === 'ArrowUp') {
      if (index > 1 && index <= this.questionSets.length) {
        target = index - 1;
      }
      else {
        target = this.questionSets.length;
      }
    }
    else if (key === 'ArrowDown') {
      if (index > -1 && index < this.questionSets.length) {
        target = index + 1;
      }
      else {
        target = 1;
      }
    }
    return target;
  }
  get el() { return getElement(this); }
};
BpSdkQuestionSetNavigation.style = bpSdkQuestionSetNavigationCss;

export { BpSdkQuestionSetNavigation as bp_sdk_question_set_navigation };
